# ORTEIL_IDLE_GAME_MAKER_CODE_GENERATOR

A tool which is used to quickly generate 
Orteil Idle Game Maker code to shorten 
our time taken in developing an idle game 
using the tool "Orteil Idle Game Maker".

# Installation

pip install ORTEIL-IDLE-GAME-MAKER-CODE-GENERATOR

# Usage

Install this library using the command in the section 'Installation'. 
Then, write the Python code 
"import ORTEIL_IDLE_GAME_MAKER_CODE_GENERATOR" to import this 
library. Next step, you can import the function 'main', 'clear',
'lets_make_a_game', or 'settings' from this library.

# Executable File

The executable file is downloadable from 
https://github.com/GlobalCreativeCommunityFounder/ORTEIL_IDLE_GAME_MAKER_CODE_GENERATOR/blob/main/ORTEIL_IDLE_GAME_MAKER_CODE_GENERATOR/orteil_idle_game_maker_code_generator.exe.
Once you download it and run the file, you will be asked to input 
information regarding the idle game you want to develop using 
"Orteil Idle Game Maker" tool.

# How To Use The Executable File?

First, open by double clicking the file "orteil_idle_game_maker_code_generator.exe". How the
executable file looks like is shown in the image below.

![Executable File](images/Executable File.png)

## Getting Started

Once you run the application, you will be asked whether you 
want to continue using "Orteil Idle Game Maker Code Generator"
tool or not. If you enter 'Y', you will proceed to inputting 
information regarding the idle game you want to develop. Enterring 
anything else will quit the application.

![Getting Started](images/Getting Started.png)

## Let's make a game!

In this section, you will be asked to input the name of the game,
your name, and the game's description.

![Let's make a game](images/Lets Make a Game.png)

## Settings

In this section, you will be asked to input the link to background image file,
building cost increase and refund, spritesheet details, and 
link to stylesheet file.

![Settings](images/Settings.png)

## Layout

In this section, you will be asked to input details about the game's box keys
in its layout. If you input 0, default layout will be used. Else, you will be told
to enter information about the box keys.

![Layout](images/Layout.png)

## Buttons

In this section, you will be asked to input details about the button you want to add 
to your game.

![Buttons](images/Buttons.png)

## Resources

In this section, you will be asked to input details about the resources you want to add 
to your game.

![Resources](images/Resources.png)

## Shinies

In this section, you will be asked to input details about the shinies you want to add 
to your game.

![Shinies](images/Shinies.png)

## Buildings

In this section, you will be asked to input details about the buildings you want to add 
to your game.

![Buildings](images/Buildings.png)

## Upgrades

In this section, you will be asked to input details about the upgrades you want to add 
to your game.

![Upgrades](images/Upgrades.png)

## Achievements

In this section, you will be asked to input details about the achievements you want to add 
to your game.

![Achievements](images/Achievements.png)

## Success

Once you have successfully input all the required information about the game you want to develop, 
something like in the image below will be shown. You can enter 'Y' if you would like to use the tool 
again to develop another game.

![Success](images/Success.png)

# Repl.it Repl

"Orteil Idle Game Maker Code Generator" is also available on
repl.it as a web app. To run the tool on repl.it, go to 
https://replit.com/@GCCFounder/ORTEILIDLEGAMEMAKERCODEGENERATOR#main.py
and then press the "Run" button.